<?php

// Theme-Optionen aktivieren

require_once ( get_stylesheet_directory() . '/theme-options.php' );


//Eigener Hintergrund

$args = array(
	'default-color' => 'fff',
);

add_theme_support( 'custom-background', $args );


//Eigenes Logo

$defaults = array(
	'default-image'          => get_template_directory_uri() . '/images/logo.png',
	'random-default'         => false,
	'width'                  => 300,
	'height'                 => 80,
	'flex-height'            => true,
	'flex-width'             => true,
	'header-text'            => false,
	'uploads'                => true,
);

add_theme_support( 'custom-header', $defaults );


// Unterstützung für Post-Formate

add_theme_support( 'post-formats', array( 
	'aside', 
	'gallery', 
	'link', 
	'image',
	'quote', 
	'status', 
	'video',
	'audio', 
	'chat' 
	)
);

	
// Post Thumbnails aktivieren

$options = get_option( 'og_theme_options' );

if ($options['post_thumb'] == 1) {

	if (function_exists('add_theme_support')) {
	add_theme_support('post-thumbnails', array('post'));

		set_post_thumbnail_size(50, 50, true);
		add_image_size( 'big-thumbnail', 250, 250 ); 
		add_image_size( 'medium-thumbnail', 100, 100 ); 
		add_image_size( 'small-thumbnail', 25, 25 ); 
		add_image_size( 'xsmall-thumbnail', 20, 20 ); 
	}

}


//Post-Thumbnails in der Artikelansicht im Backend anzeigen

$options = get_option( 'og_theme_options' );

if ($options['post_thumb'] == 1) {

	if ( !function_exists('fb_AddThumbColumn') && function_exists('add_theme_support') ) {

	add_theme_support('post-thumbnails', array( 'post', 'page' ) );

	function fb_AddThumbColumn($cols) {
       		$cols['thumbnail'] = ('Thumbnail');
	        return $cols;
	}

	function fb_AddThumbValue($column_name, $post_id) {

	            $width = (int) 35;
        	    $height = (int) 35;

	            if ( 'thumbnail' == $column_name ) {
        	        // thumbnail of WP 2.9
                	$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
	                // image from gallery
        	        $attachments = get_children( array('post_parent' => $post_id, 'post_type' => 'attachment', 'post_mime_type' => 'image') );
                	if ($thumbnail_id)
	                    $thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
        	        elseif ($attachments) {
                	    foreach ( $attachments as $attachment_id => $attachment ) {
                        	$thumb = wp_get_attachment_image( $attachment_id, array($width, $height), true );
	                    }
        	        }
                	    if ( isset($thumb) && $thumb ) {
                        	echo $thumb;
	                    } else {
        	                echo ('None');
                	    }
	            }
   	}

	    add_filter( 'manage_posts_columns', 'fb_AddThumbColumn' );
	    add_action( 'manage_posts_custom_column', 'fb_AddThumbValue', 10, 2 );
	}

}

// Sidebars registrieren

if ( function_exists('register_sidebar') )
register_sidebar(array(
	'name' => 'Fußzeile links',
	'id' => 'footer1',
	)
);

register_sidebar(array(
	'name' => 'Fußzeile mitte links',
	'id' => 'footer2',
	)
);

register_sidebar(array(
	'name' => 'Fußzeile mitte rechts',
	'id' => 'footer3',
	)
);

register_sidebar(array(
	'name' => 'Fußzeile rechts',
	'id' => 'footer4',
	)
);

register_sidebar(array(
	'name' => 'Sidebar',
	'id' => 'sidebar',
	)
);


// Feed Links

if (function_exists('add_theme_support')) {
add_theme_support('automatic-feed-links');
}


// Maximale Breite des Inhalts festlegen

if ( ! isset( $content_width ) ) $content_width = 900;


// Anpassungen für das Kommentar-Formular

function my_fields($fields) {
	$fields['author'] = '<p class="comment-form-author">' . '<label for="author">Name <small>(erforderlich)</small></label> ' . ( $req ? '<span class="required">(erforderlich)</span>' : '' ) .
                    '<br/><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';
	$fields['email'] = '<p class="comment-form-email"><label for="email">Mail-Adresse <small>(erforderlich)</small></label> ' . ( $req ? '<span class="required">*</span>' : '' ) .
                    '<br/><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';
	$fields['url'] = '<p class="comment-form-url"><label for="url">Webseite <small>(optional)</small></label>' .
                    '<br/><input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';
return $fields;
}
add_filter('comment_form_default_fields','my_fields');



// Anzahl der Wörter für die Kurzfassung der Artikel (the_excerpt)

function custom_excerpt_length( $length ) {

$options = get_option( 'og_theme_options' );

	if ($options['excerpt_zeichen']) { 
		return $options['excerpt_zeichen'];
	} else { 
		return 55;
	}
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );
 

// Weiterlesen-Link bei Kurzfassung der Artikel (the_excerpt)

$options = get_option( 'og_theme_options' );

if ($options['excerpt_moretag'] == 1) {
	function new_excerpt_more($more) {
		global $post;
		return ' <p><a class="more-link" href="'. get_permalink($post->ID) . '">Weiterlesen &rarr;</a></p>';
}
add_filter('excerpt_more', 'new_excerpt_more');
}


// Shortcodes für Mehrspalten-Layout

function zweispalten_shortcode( $atts, $content = null ) {
	return '<div class="zweispalten">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'zweispalten', 'zweispalten_shortcode' );

function dreispalten_shortcode( $atts, $content = null ) {
	return '<div class="dreispalten">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'dreispalten', 'dreispalten_shortcode' );


// Shortcode für Infoboxen

function infobox_shortcode ( $atts, $content = null) {

extract( shortcode_atts( array(
      'color' => '', 
	   ), $atts ) );
      return '<div class="infobox ' . $color . '">' . do_shortcode($content) . '</div>';

}
add_shortcode('infobox', 'infobox_shortcode');


// Shortcode für Buttons

function button_shortcode ( $atts, $content = null) {

extract( shortcode_atts( array(
	'color' => '', 
	'size' => '', 
	'link' => '',
	'ausrichtung' => '',
	), $atts ) );
	return '<a href="' . $link . '" class="button ' . $size . ' ' . $ausrichtung . ' ' . $color . '">' . $content . '</a>';
}
add_shortcode('button', 'button_shortcode');


// Shortcodes in der Kurzfassung entfernen

function custom_excerpt($text = '') {
	$raw_excerpt = $text;
	if ( '' == $text ) {
		$text = get_the_content('');
                // $text = strip_shortcodes( $text );
		$text = do_shortcode( $text );
		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]>', $text);
		$excerpt_length = apply_filters('excerpt_length', 55);
		$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
		$text = wp_trim_words( $text, $excerpt_length, $excerpt_more );
	}
	return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
}
remove_filter( 'get_the_excerpt', 'wp_trim_excerpt'  );
add_filter( 'get_the_excerpt', 'custom_excerpt'  );


?>